@@ -767,11 +767,18 @@ class HarvestText(EntNetworkMixin, EntRetrieveMixin, ParsingMixin, SentimentMixi
         if remove_tags:
             text = w3lib.html.remove_tags(text)
         if remove_url:
-            zh_puncts1 = "，；、。！？（）《》【】"
-            URL_REGEX = re.compile(
-                r'(?i)((?:https?://|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}/)(?:[^\s()<>' + zh_puncts1 + ']+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:\'".,<>?«»“”‘’' + zh_puncts1 + ']))',
-                re.IGNORECASE)
-            text = re.sub(URL_REGEX, "", text)
+            try:
+                URL_REGEX = re.compile(
+                    r'(?i)http[s]?://(?:[a-zA-Z]|[0-9]|[#$%*-;=?&@~.&+]|[!*,])+',
+                    re.IGNORECASE)
+                text = re.sub(URL_REGEX, "", text)
+            except:
+                # sometimes lead to "catastrophic backtracking"
+                zh_puncts1 = "，；、。！？（）《》【】"
+                URL_REGEX = re.compile(
+                    r'(?i)((?:https?://|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}/)(?:[^\s()<>' + zh_puncts1 + ']+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:\'".,<>?«»“”‘’' + zh_puncts1 + ']))',
+                    re.IGNORECASE)
+                text = re.sub(URL_REGEX, "", text)
         if norm_url:
             text = urllib.parse.unquote(text)
         if email:
